EdgeHandle

Struct EdgeHandle 

pub struct EdgeHandle<'a> { /* private fields */ }
Mutable builder handle for an Edge in a channel.

Implementations

Source

impl EdgeHandle<'_>

pub fn edge_mut(&mut self) -> &mut Edge

Mutable access to the underlying Edge.

pub fn p4(&mut self, p4: impl Into<Vec4>) -> &mut Self

Assign an explicit symbolic four-momentum.

pub fn properties(&mut self, properties: &ParticleProperties) -> &mut Self

Attach particle properties.

pub fn output(&mut self) -> &mut Self

Retain this edge in generated event output.

pub fn generated_only(&mut self) -> &mut Self

Use this edge internally during generation without retaining it.

pub fn mass_proposal(&mut self, proposal: impl Into<MassProposal>) -> &mut Self

Assign a generated invariant-mass proposal.

pub fn initial(&mut self, source: InitialMomentum) -> &mut Self

Assign an initial-state momentum source.

pub fn initial_p4(&mut self, p4: RealVec4) -> &mut Self

Assign a fixed initial-state four-momentum in (E, px, py, pz) order.

pub fn initial_momentum(&mut self, momentum: RealVec3) -> &mut Self

Assign a fixed initial-state three-momentum.

pub fn initial_energy_direction( &mut self, energy: f64, direction: RealVec3, ) -> &mut Self

Assign a fixed energy and direction for an initial-state edge.

pub fn initial_energy_source_direction( &mut self, energy: ScalarSource, direction: RealVec3, ) -> &mut Self

Assign a sampled energy source and fixed direction for an initial-state edge.