LadduPhysicsError

Enum LadduPhysicsError 

pub enum LadduPhysicsError {
    ConversionError(&'static str),
    ParseError {
        name: String,
        object: String,
    },
    MissingParticleProperty {
        property: &'static str,
    },
    InvalidValue {
        name: String,
        expected: String,
        actual: String,
    },
    InvalidLength {
        name: String,
        expected: String,
        actual: String,
    },
    InvalidRelation {
        relation: String,
    },
    UnsupportedValue {
        name: String,
        supported: String,
        actual: String,
    },
    NumericOverflow {
        operation: String,
    },
    Custom(String),
}
Errors raised while constructing or evaluating physics objects.

Variants



ConversionError(&'static str)

An error that should be used to convert TryFrom to LadduPhysicsError.



ParseError

An error which occurs when the user tries to parse an invalid string of text, typically into an enum variant.

Fields

name: String

The string which was parsed

object: String

The name of the object it failed to parse into



MissingParticleProperty

A particle is missing the requested property

Fields

property: &'static str

The name of the missing property



InvalidValue

A single value violates a domain constraint.

Fields

name: String

Name of the invalid input.

expected: String

Description of the accepted domain.

actual: String

Supplied value.



InvalidLength

A collection length or shape is invalid.

Fields

name: String

Name of the invalid collection.

expected: String

Description of the required length or shape.

actual: String

Supplied length or shape.



InvalidRelation

A relation between multiple values, quantum numbers, or particle properties is invalid.

Fields

relation: String

Description of the violated relation.



UnsupportedValue

A value is valid in principle but not implemented/supported here.

Fields

name: String

Name of the unsupported input.

supported: String

Description of the supported alternatives.

actual: String

Supplied value.



NumericOverflow

An integer operation overflowed.

Fields

operation: String

Operation that overflowed.



Custom(String)

A free-form error message for internal compatibility paths.

Implementations

Source

impl LadduPhysicsError

pub fn invalid_value( name: impl Into<String>, expected: impl Into<String>, actual: impl ToString, ) -> Self

Construct an invalid-value error.

pub fn invalid_length( name: impl Into<String>, expected: impl Into<String>, actual: impl ToString, ) -> Self

Construct an invalid-length or shape error.

pub fn invalid_relation(relation: impl Into<String>) -> Self

Construct an invalid-relation error.

pub fn unsupported_value( name: impl Into<String>, supported: impl Into<String>, actual: impl ToString, ) -> Self

Construct an unsupported-value error.

pub fn numeric_overflow(operation: impl Into<String>) -> Self

Construct a numeric-overflow error.