pub enum ExternalId {
Code {
value: i64,
},
Label {
value: String,
},
}Expand description
An external identifier associated with a physical particle species.
Variants
Implementations
Sourceimpl ExternalId
impl ExternalId
Sourcepub fn label(value: impl Into<String>) -> Self
pub fn label(value: impl Into<String>) -> Self
Construct a textual identifier in an arbitrary namespace.
Sourcepub fn code_value(&self) -> Option<i64>
pub fn code_value(&self) -> Option<i64>
Return the numeric value, if this is a numeric identifier.
Sourcepub fn label_value(&self) -> Option<&str>
pub fn label_value(&self) -> Option<&str>
Return the textual value, if this is a textual identifier.