pub struct PartialWave {
pub j: J,
pub l: L,
pub s: S,
}Expand description
A partial wave defined by a total angular momentum, J, an orbital angular momentum, L, and
and intrinsic spin, S.
Fields
j: JThe total angular momentum of the wave
l: LThe orbital angular momentum of the wave
s: SThe spin of the wave
Implementations
Sourceimpl PartialWave
impl PartialWave
Sourcepub fn new(j: J, l: L, s: S) -> LadduPhysicsResult<Self>
pub fn new(j: J, l: L, s: S) -> LadduPhysicsResult<Self>
Construct a new partial wave from the given angular momentum quantum numbers.
Errors
Returns LadduPhysicsError when j, l, and s violate angular
momentum coupling rules.
Sourcepub fn label(&self) -> String
pub fn label(&self) -> String
Get the spectroscopic label for the wave in the form {2s+1}{l}{j} where l is represented by
its spectroscopic letter equivalent (S for 0, P for 1, etc.).
Sourcepub fn validate_coupling(j: J, l: L, s: S) -> LadduPhysicsResult<()>
pub fn validate_coupling(j: J, l: L, s: S) -> LadduPhysicsResult<()>
Validate the set of angular momentum quantum numbers which define a partial wave.
Errors
Returns LadduPhysicsError when j lies outside the range permitted
by l and s or has incompatible integer/half-integer parity.