pub struct RuleReport {
pub checks: Vec<RuleCheck>,
}Expand description
Detailed results from evaluating a RuleSet against one candidate.
Fields
checks: Vec<RuleCheck>Individual checks, ordered by RuleKind.
Implementations
Sourceimpl RuleReport
impl RuleReport
Sourcepub fn is_allowed(&self) -> bool
pub fn is_allowed(&self) -> bool
Return whether no enforced rule rejected the candidate.
Sourcepub fn failures(&self) -> impl Iterator<Item = &RuleCheck>
pub fn failures(&self) -> impl Iterator<Item = &RuleCheck>
Iterate over checks that rejected the candidate.
Sourcepub fn warnings(&self) -> impl Iterator<Item = &RuleCheck>
pub fn warnings(&self) -> impl Iterator<Item = &RuleCheck>
Iterate over missing-input warnings.
Sourcepub fn unknowns(&self) -> impl Iterator<Item = &RuleCheck>
pub fn unknowns(&self) -> impl Iterator<Item = &RuleCheck>
Iterate over checks whose missing inputs were allowed.
Sourcepub fn ignored(&self) -> impl Iterator<Item = &RuleCheck>
pub fn ignored(&self) -> impl Iterator<Item = &RuleCheck>
Iterate over rules which were intentionally ignored.
Sourcepub fn outcome(&self, rule: RuleKind) -> Option<&RuleOutcome>
pub fn outcome(&self, rule: RuleKind) -> Option<&RuleOutcome>
Retrieve the outcome for a particular rule, if it was configured.
Sourcepub fn has_failures(&self) -> bool
pub fn has_failures(&self) -> bool
Return whether at least one check rejected the candidate.
Sourcepub fn has_unknowns(&self) -> bool
pub fn has_unknowns(&self) -> bool
Return whether at least one check allowed unknown inputs.
Sourcepub fn has_ignored(&self) -> bool
pub fn has_ignored(&self) -> bool
Return whether at least one configured rule was ignored.