pub struct SpinState { /* private fields */ }Expand description
A validated spin state with spin and projection stored as doubled quantum numbers.
Implementations
Sourceimpl SpinState
impl SpinState
Sourcepub fn new(spin: J, projection: M) -> LadduPhysicsResult<Self>
pub fn new(spin: J, projection: M) -> LadduPhysicsResult<Self>
Construct a spin state after validating projection bounds and parity.
Errors
Returns LadduPhysicsError when projection is outside the spin
range or has incompatible integer/half-integer parity.
Sourcepub const fn projection(self) -> M
pub const fn projection(self) -> M
Return the spin projection quantum number.