pub struct EdgeHandle<'a> { /* private fields */ }Expand description
Mutable builder handle for an Edge in a channel.
Implementations
Sourceimpl EdgeHandle<'_>
impl EdgeHandle<'_>
Sourcepub fn p4(&mut self, p4: impl Into<Vec4>) -> &mut Self
pub fn p4(&mut self, p4: impl Into<Vec4>) -> &mut Self
Assign an explicit symbolic four-momentum.
Sourcepub fn properties(&mut self, properties: &ParticleProperties) -> &mut Self
pub fn properties(&mut self, properties: &ParticleProperties) -> &mut Self
Attach particle properties.
Sourcepub fn generated_only(&mut self) -> &mut Self
pub fn generated_only(&mut self) -> &mut Self
Use this edge internally during generation without retaining it.
Sourcepub fn mass_proposal(&mut self, proposal: impl Into<MassProposal>) -> &mut Self
pub fn mass_proposal(&mut self, proposal: impl Into<MassProposal>) -> &mut Self
Assign a generated invariant-mass proposal.
Sourcepub fn initial(&mut self, source: InitialMomentum) -> &mut Self
pub fn initial(&mut self, source: InitialMomentum) -> &mut Self
Assign an initial-state momentum source.
Sourcepub fn initial_p4(&mut self, p4: RealVec4) -> &mut Self
pub fn initial_p4(&mut self, p4: RealVec4) -> &mut Self
Assign a fixed initial-state four-momentum in (E, px, py, pz) order.
Sourcepub fn initial_momentum(&mut self, momentum: RealVec3) -> &mut Self
pub fn initial_momentum(&mut self, momentum: RealVec3) -> &mut Self
Assign a fixed initial-state three-momentum.
Sourcepub fn initial_energy_direction(
&mut self,
energy: f64,
direction: RealVec3,
) -> &mut Self
pub fn initial_energy_direction( &mut self, energy: f64, direction: RealVec3, ) -> &mut Self
Assign a fixed energy and direction for an initial-state edge.
Sourcepub fn initial_energy_source_direction(
&mut self,
energy: ScalarSource,
direction: RealVec3,
) -> &mut Self
pub fn initial_energy_source_direction( &mut self, energy: ScalarSource, direction: RealVec3, ) -> &mut Self
Assign a sampled energy source and fixed direction for an initial-state edge.