pub enum LadduPhysicsError {
ConversionError(&'static str),
ParseError {
name: String,
object: String,
},
MissingParticleProperty {
property: &'static str,
},
InvalidValue {
name: String,
expected: String,
actual: String,
},
InvalidLength {
name: String,
expected: String,
actual: String,
},
InvalidRelation {
relation: String,
},
UnsupportedValue {
name: String,
supported: String,
actual: String,
},
NumericOverflow {
operation: String,
},
Custom(String),
}Expand description
Errors raised while constructing or evaluating physics objects.
Variants
ConversionError(&'static str)
An error that should be used to convert TryFrom to LadduPhysicsError.
ParseError
An error which occurs when the user tries to parse an invalid string of text, typically into an enum variant.
Fields
MissingParticleProperty
A particle is missing the requested property
InvalidValue
A single value violates a domain constraint.
Fields
InvalidLength
A collection length or shape is invalid.
Fields
InvalidRelation
A relation between multiple values, quantum numbers, or particle properties is invalid.
UnsupportedValue
A value is valid in principle but not implemented/supported here.
Fields
NumericOverflow
An integer operation overflowed.
Custom(String)
A free-form error message for internal compatibility paths.
Implementations
Sourceimpl LadduPhysicsError
impl LadduPhysicsError
Sourcepub fn invalid_value(
name: impl Into<String>,
expected: impl Into<String>,
actual: impl ToString,
) -> Self
pub fn invalid_value( name: impl Into<String>, expected: impl Into<String>, actual: impl ToString, ) -> Self
Construct an invalid-value error.
Sourcepub fn invalid_length(
name: impl Into<String>,
expected: impl Into<String>,
actual: impl ToString,
) -> Self
pub fn invalid_length( name: impl Into<String>, expected: impl Into<String>, actual: impl ToString, ) -> Self
Construct an invalid-length or shape error.
Sourcepub fn invalid_relation(relation: impl Into<String>) -> Self
pub fn invalid_relation(relation: impl Into<String>) -> Self
Construct an invalid-relation error.
Sourcepub fn unsupported_value(
name: impl Into<String>,
supported: impl Into<String>,
actual: impl ToString,
) -> Self
pub fn unsupported_value( name: impl Into<String>, supported: impl Into<String>, actual: impl ToString, ) -> Self
Construct an unsupported-value error.
Sourcepub fn numeric_overflow(operation: impl Into<String>) -> Self
pub fn numeric_overflow(operation: impl Into<String>) -> Self
Construct a numeric-overflow error.